@@ -14,9 +14,11 @@ class UniteController
         add_action('partTimeImport', [$this, 'unitePartTimeImport'], 10);
 
         add_action('fullTimeImport', [$this, 'uniteImport'], 10);
+
+        add_action('init', [$this, 'unitePartTimeImport']);
     }
 
-    public function startUniteFullTimeImport()
+    public static function startUniteFullTimeImport()
     {
         if ( !wp_next_scheduled('fullTimeImport') ) {
             //run this in 30 seconds time
@@ -29,85 +31,65 @@ class UniteController
         ini_set('memory_limit', '-1');
         ini_set('max_execution_time', '0');
 
-        echo "Unit-E Import\n";
-
         $courseInstances = $this->getAllCurrentCourseCodes();
-        $allCourseData = $this->getUniteData("http://195.194.136.164/NescolData/UniteWs.asmx/GetCourseAll");
-
+        $allCourseData = $this->getUniteData("http://195.194.136.164/NescolData/UniteWs.asmx/GetCourseAll");        
+        $allCourses = $this->getCourseParents();
+        
         $found = 0;
         $notFound = 0;
+        $added = 0;
+        $updated = 0;
 
         ob_start();
 
-        //Add missing instances
         foreach ($allCourseData as $ref => $info) {
+            $today = strtotime("now");
+            $courseStart = $info['START_DATE'];
+
+            if($courseStart < $today) {
+                //the start date has passed, lets skip it
+                continue;
+            }
+
             if (!array_key_exists($ref, $courseInstances)) {
-                //get parent reference
-                //if it doesn't exist, create it
                 $parts = explode('-', $ref);
                 $courseCode = $parts[0];
                 $instance = array_pop($parts);
+                $showStatus = $info['ONLINE'] == 'Y' ? true : false;
 
-                $args = array(
-                    'meta_key'   => 'course_reference',
-                    'meta_value' => $courseCode,
-                    'meta_compare' => '=',
-                    'posts_per_page ' => 1,
-                    'post_type' => 'course',
-                    'post_status' => 'any'
-                );
-                $query = new \WP_Query($args);
+                if (array_key_exists($courseCode, $allCourses)) {
+                    $post_id = $allCourses[$courseCode];
 
-                if ($query->have_posts()) {
-                    while ($query->have_posts()) {
-                        $query->the_post();
-
-                        $found++;
-                        echo($ref . ' : ' . $courseCode . ": FOUND IN WP DATA\n");
-
-                        $row= ['code' => implode('-', $parts),
-                                'instance' => $instance];
-
-                        add_row('course_instances', $row);
+                    $found++;
+                    $instances = get_field("course_instances", $post_id);
+                    $row = ['code' => implode('-', $parts), 'instance' => $instance, 'show_on_site' => $showStatus];
+                    if(add_row('field_5d5d6a2d24559', $row, $post_id))
+                    {
+                        $added++;
                     }
-                    wp_reset_postdata();
+                    $this->updateCourseInstance($post_id, $allCourseData[$ref]);
                 } else {
                     $notFound++;
-                    echo($ref . ' : ' . $courseCode . ": NOT FOUND IN WP DATA\n");
-                }
-            }
-        }
-
-        echo("$found/$notFound\n");
-
-        $courseInstances = $this->getAllCurrentCourseCodes();
-
-        $i = 1;
-        $totalCourseInstances = count($courseInstances);
-
-        foreach ($courseInstances as $reference => $courseInstance) {
-            $currentCount = '[' . str_pad($i++, 4, '0', STR_PAD_LEFT) . '/' . $totalCourseInstances . '] ';
-
-            if (array_key_exists($reference, $allCourseData)) {
-                if ($courseInstance->instance == null || $courseInstance->instance == $allCourseData[$reference]['INSTANCE']) {
-                    echo($currentCount . $reference . " and instance " . $courseInstance->instance . ": MATCHED\n");
-                    $this->updateCourseInstance($courseInstance->post_id, $allCourseData[$reference]);
-                } else {
-                    echo($currentCount . $reference . ": IS FOUND, BUT NOT MATCHING " . $courseInstance->instance . "INSTANCE IN UNIT-E DATA\n");
                 }
             } else {
-                echo($currentCount . $reference . ": NOT FOUND IN UNIT-E DATA\n");
+                $post_id = $courseInstances[$ref]['post_id'];
+                $this->updateCourseInstance($post_id, $allCourseData[$ref]);
+                $updated++;
             }
-            flush();
         }
 
+        echo $found . 'were found <br>';
+        echo $notFound . 'were not found <br>';
+        echo $added . 'were added <br>';
+        echo $updated . 'were updated <br>';
+
         $info = ob_get_clean();
 
-        wp_mail( 'shane@blue2.co.uk', 'Full Time Import', $info );
+        wp_mail( 'shane@blue2.co.uk', 'Full Time Import Results', $info );
         die;
     }
 
-    public function startUnitePartTimeImport()
+    public static function startUnitePartTimeImport()
     {
         if ( !wp_next_scheduled('partTimeImport') ) {
             //run this in 30 seconds time
@@ -120,91 +102,63 @@ class UniteController
         ini_set('memory_limit', '-1');
         ini_set('max_execution_time', '0');
 
-        echo "Unit-E Import\n";
-
         $courseInstances = $this->getAllCurrentCourseCodes();
         $allCourseData = $this->getPartTimeUniteData("http://195.194.136.164/NescolData/UniteWs.asmx/GetPartTimeCourseFeed?year=2021");
-
+        $allCourses = $this->getCourseParents();
+        
         $found = 0;
         $notFound = 0;
-
-        $courses = [];
+        $added = 0;
+        $updated = 0;
 
         ob_start();
 
         foreach ($allCourseData as $ref => $info) {
+            $today = strtotime("now");
+            $courseStart = $info['STARTDATE'];
+
+            if($courseStart < $today) {
+                //the start date has passed, lets skip it
+                continue;
+            }
+
             if (!array_key_exists($ref, $courseInstances)) {
-                //get parent reference
-                //if it doesn't exist, create it
                 $parts = explode('-', $ref);
                 $courseCode = $parts[0];
                 $instance = array_pop($parts);
                 $showStatus = $info['ONLINE'] == 'Y' ? true : false;
 
-                if (!array_key_exists($courseCode, $courses)) {
-                    $args = array(
-                        'meta_key' => 'course_reference',
-                        'meta_value' => $courseCode,
-                        'meta_compare' => '=',
-                        'posts_per_page ' => 1,
-                        'post_type' => 'course',
-                        'post_status' => 'any'
-                    );
-                    $query = new \WP_Query($args);
+                if (array_key_exists($courseCode, $allCourses)) {
+                    $post_id = $allCourses[$courseCode];
 
-                    if ($query->have_posts()) {
-                        while ($query->have_posts()) {
-                            $query->the_post();
-
-                            $courses[$courseCode] = get_the_ID();
-
-                            $found++;
-                            echo($ref . ' : ' . $courseCode . ": FOUND IN WP DATA\n");
-
-                            $row = ['code' => implode('-', $parts), 'instance' => $instance, 'show_on_site' => $showStatus];
-                            add_row('course_instances', $row);
-
-                        }
-                        wp_reset_postdata();
-                    } else {
-                        $notFound++;
-                        echo($ref . ' : ' . $courseCode . ": NOT FOUND IN WP DATA\n");
-                    }
-                } else {
+                    $found++;
+                    $instances = get_field("course_instances", $post_id);
                     $row = ['code' => implode('-', $parts), 'instance' => $instance, 'show_on_site' => $showStatus];
-                    add_row('course_instances', $row, $courses[$courseCode]);
-                }
-            } else {
-               $this->updatePartTimeCourseInstance($courseInstances[$ref]->post_id, $allCourseData[$ref]);
-            }
-        }
-        
-        echo("$found/$notFound\n");
-
-        $courseInstances = $this->getAllCurrentCourseCodes();
-
-        $i = 1;
-        $totalCourseInstances = count($courseInstances);
-
-        foreach ($courseInstances as $reference => $courseInstance) {
-            $currentCount = '[' . str_pad($i++, 4, '0', STR_PAD_LEFT) . '/' . $totalCourseInstances . '] ';
-
-            if (array_key_exists($reference, $allCourseData)) {
-                if ($courseInstance->instance == null || $courseInstance->instance == $allCourseData[$reference]['INSTANCE']) {
-                    echo($currentCount . $reference . " and instance " . $courseInstance->instance . ": MATCHED\n");
-                    $this->updateCourseInstance($courseInstance->post_id, $allCourseData[$reference]);
+                    if(add_row('field_5d5d6a2d24559', $row, $post_id))
+                    {
+                        $added++;
+                    }
+                    $this->updatePartTimeCourseInstance($post_id, $allCourseData[$ref]);
                 } else {
-                    echo($currentCount . $reference . ": IS FOUND, BUT NOT MATCHING " . $courseInstance->instance . "INSTANCE IN UNIT-E DATA\n");
+                    $notFound++;
                 }
             } else {
-                echo($currentCount . $reference . ": NOT FOUND IN UNIT-E DATA\n");
+                $post_id = $courseInstances[$ref]['post_id'];
+                $this->updatePartTimeCourseInstance($post_id, $allCourseData[$ref]);
+                $updated++;
             }
-            flush();
         }
 
+        echo $found . 'were found <br>';
+        echo $notFound . 'were not found <br>';
+        echo $added . 'were added <br>';
+        echo $updated . 'were updated <br>';
+
         $info = ob_get_clean();
 
-        wp_mail( 'shane@blue2.co.uk', 'Part Time Import', $info );
+        echo $info;
+
+        wp_mail( 'shane@blue2.co.uk', 'Part Time Import Results', $info );
 
         die();
     }
@@ -245,8 +199,6 @@ class UniteController
         return $uniteCourses;
     }
 
-
-
     private function uniteDateToString($date)
     {
         if (trim($date) !== '') {
@@ -263,26 +215,63 @@ class UniteController
 
     public function getAllCurrentCourseCodes()
     {
-        $query = 'SELECT pm.meta_value AS `code`, pm.post_id, pm2.meta_value AS `instance`, p.ID AS `id`, p.post_status, p.ID
-                FROM pex_nescoldev_posts p
-                JOIN pex_nescoldev_postmeta pm ON p.ID = pm.post_id AND pm.meta_key LIKE "course_instances_%_code"
-                JOIN pex_nescoldev_postmeta pm2 ON p.ID = pm2.post_id AND pm2.meta_key LIKE "course_instances_%_instance" AND
-                SUBSTRING(pm2.meta_key, 1, 19) = SUBSTRING(pm.meta_key, 1, 19)
-                WHERE post_status = "publish" AND p.post_type=\'course\'
-                ORDER BY p.ID';
-        global $wpdb;
-        $results = $wpdb->get_results($query);
-
         $instances = [];
-        foreach ($results as $result) {
-            $instRef = $result->instance ?: 1;
-            $uniqueCode = $result->code . '-' . $instRef;
-            $instances[$uniqueCode] = $result;
-        }
+
+        ini_set('memory_limit', '-1');
+        ini_set('max_execution_time', '0');
+
+        $args = array(
+            'post_type' => 'course',
+            'posts_per_page'   => -1,   
+        );
+        $query = new \WP_Query($args);
+
+        while ( $query->have_posts() ) : $query->the_post();
+            $post_id = get_the_id();
+            if (have_rows('course_instances', $post_id)) {
+                $postStatus = get_post_status ($post_id);
+                while (have_rows('course_instances', $post_id)) {
+                    the_row();
+                    $instanceNumber = get_sub_field('field_5dc58094fcce7');
+                    $code = get_sub_field('field_5d5d6a622455d');
+                    $uniqueCode = $code . '-' . $instanceNumber;
+
+                    $instances[$uniqueCode] = [
+                        "code" => $code,
+                        "post_id" => $post_id,
+                        "instance" => $instanceNumber,
+                        "id" => $post_id,
+                        "post_status" => $postStatus,
+                        "ID" => $post_id
+                    ];
+                }
+            }
+        endwhile;
+
+        wp_reset_postdata();
 
         return $instances;
     }
 
+    public function getCourseParents() {
+        $args = array(
+            'post_type' => 'course',
+            'posts_per_page'   => -1,
+            'post_status'   =>   'any',  
+        );
+        $query = new \WP_Query($args);
+        $courseParents = [];
+
+        while ( $query->have_posts() ) : $query->the_post();
+            $key = get_post_meta( get_the_ID(), 'course_reference', true );;
+            $courseParents[$key] = get_the_ID();
+        endwhile;
+
+        wp_reset_postdata();
+
+        return $courseParents;
+    }
+
     private function updateCourseInstance($courseId, $courseData)
     {
         $rows = get_field('course_instances', $courseId);
@@ -322,13 +311,9 @@ class UniteController
 
     private function updatePartTimeCourseInstance($courseId, $courseData)
     {
-        $rows = get_field('course_instances', $courseId);
+        $rows = get_field('field_5d5d6a2d24559', $courseId);
         foreach ($rows as $key => $row) {
-
-            echo "Row Code: " . $row['code'] . "--------- CourseData (CREF): " . $courseData['CREF'] . "--------- Instances: " . $row['instance'] . "-" . $courseData['INSTANCE'] . "\n";
-
             if ($row['code'] === $courseData['CREF'] && $row['instance'] === $courseData['INSTANCE']) {
-
                 if($courseData['STARTDATE']) {
                     $startDate = $this->uniteDateToString($courseData['STARTDATE']);
                     if ($startDate !== null) {
@@ -381,7 +366,6 @@ class UniteController
                     }
                 }
 
-                //$row['show_on_site'] = !$this->uniteTextToBoolean($courseData['HIDE']);
                 $row['online'] = $this->uniteTextToBoolean($courseData['ONLINE']);
 
                 $test = update_row('course_instances', $key+1, $row, $courseId);
